@@ -10,7 +10,7 @@ TODO: Split writeSLHA into writeSLHA{Blocks,Decays}
 from __future__ import with_statement
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 
 
 def _autotype(var):
@@ -170,7 +170,8 @@ def readSLHA(spcstr, ignorenobr=False):
 
         ## Handle BLOCK/DECAY start lines
         if line.upper().startswith("BLOCK"):
-            match = re.match(r"BLOCK\s+(\w+)\s+(Q=\s*.+)?", line.upper())
+            #print line
+            match = re.match(r"BLOCK\s+(\w+)(\s+Q=\s*.+)?", line.upper())
             if not match:
                 continue
             blockname = match.group(1)
@@ -210,9 +211,13 @@ def readSLHA(spcstr, ignorenobr=False):
                         decays[currentdecay].add_decay(br, nda, ids)
 
     ## Try to populate Particle masses from the MASS block
-    for pid in blocks["MASS"].entries.keys():
-        if decays.has_key(pid):
-            decays[pid].mass = blocks["MASS"].entries[pid]
+    # print blocks.keys()
+    try:
+        for pid in blocks["MASS"].entries.keys():
+            if decays.has_key(pid):
+                decays[pid].mass = blocks["MASS"].entries[pid]
+    except:
+        raise Exception("No MASS block found, from which to populate particle masses")
 
     return blocks, decays
 
@@ -482,6 +487,8 @@ if __name__ == "__main__":
             print b
             print
 
+        print blocks.keys()
+
         print blocks["MASS"].entries[25]
         print
 
